CREATE TABLE `cat_alt_models` (
  `ID_mod` smallint(6) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор модели',
  `ID_mfa` smallint(4) unsigned NOT NULL COMMENT 'Идентификатор производителя',
  `ID_src` int(12) DEFAULT NULL COMMENT 'Идентификатор источника',
  `Name` varchar(90) NOT NULL COMMENT 'Наименование модели',
  `Childs` smallint(4) unsigned DEFAULT NULL COMMENT 'Количество дочерних елементов',
  `DateStart` char(7) DEFAULT NULL COMMENT 'Дата начала производства',
  `DateEnd` char(7) DEFAULT NULL COMMENT 'Дата окончания производства',
  `isVisible` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Отображемый (1 - да, 0 - нет)',
  `isDeleted` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Удаленный (1- да, 0 - нет)',
  PRIMARY KEY (`ID_mod`),
  KEY `idxSrc` (`ID_src`),
  KEY `idxMain` (`ID_mfa`,`isVisible`,`isDeleted`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Модели автомобилей для каталога неоригинальных запчастей';

CREATE TABLE `cat_alt_tree` (
  `ID_tree` smallint(6) unsigned NOT NULL,
  `ID_parent` smallint(6) unsigned NOT NULL,
  `Name` varchar(120) NOT NULL,
  `Level` tinyint(1) unsigned NOT NULL,
  `Childs` tinyint(2) unsigned DEFAULT NULL COMMENT 'Количество дочерних узлов',
  `Path` text COMMENT 'Путь к узлу по дереву',
  `Sort` smallint(4) unsigned NOT NULL,
  `ID_src` int(12) DEFAULT NULL,
  PRIMARY KEY (`ID_tree`),
  KEY `idxParent` (`ID_parent`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Дерево поиска запчастей по узлам и т.д.';

CREATE TABLE `cat_alt_suppliers` (
  `ID_sup` smallint(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор производителя',
  `ID_src` smallint(6) unsigned NOT NULL COMMENT 'Идентификатор источника',
  `Name` varchar(25) NOT NULL COMMENT 'Наименование',
  `Search` varchar(25) DEFAULT NULL COMMENT 'Для поиска по наименованию',
  `Logo` varchar(50) DEFAULT NULL COMMENT 'Логотип производителя',
  `Childs` mediumint(6) unsigned DEFAULT NULL COMMENT 'Количество запчастей в каталоге',
  `isDeleted` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Отметка на удаление (1 - удален, 0 - не уделан)',
  `isVisible` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Отображение в списках (1 - да, 0 - нет)',
  `NameFull` varchar(100) DEFAULT NULL COMMENT 'Полное название производителя',
  `Street` varchar(200) DEFAULT NULL COMMENT 'Улица',
  `PostalBox` varchar(30) DEFAULT NULL COMMENT 'Почтовый ящик (Номер ящика)',
  `PostalCountry` varchar(50) DEFAULT NULL COMMENT 'Почтовый ящик (Страна)',
  `PostalCode` varchar(30) DEFAULT NULL COMMENT 'Почтовый ящик (Индекс)',
  `CityIndex` varchar(30) DEFAULT NULL COMMENT 'Индекс города',
  `City` varchar(200) DEFAULT NULL COMMENT 'Город',
  `Phone` varchar(100) DEFAULT NULL COMMENT 'Телефон',
  `Fax` varchar(100) DEFAULT NULL COMMENT 'Факс',
  `Email` varchar(100) DEFAULT NULL COMMENT 'Електронный почтовый ящик',
  `WEB` varchar(100) DEFAULT NULL COMMENT 'Страница Интернет',
  PRIMARY KEY (`ID_sup`),
  UNIQUE KEY `idxSearch` (`Search`,`ID_sup`),
  KEY `idxSrc` (`ID_src`),
  KEY `idxMain` (`Name`,`ID_sup`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Производители неоригинальных автозапчастей';

CREATE TABLE `cat_alt_types` (
  `ID_typ` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор модификации',
  `ID_mfa` smallint(4) unsigned NOT NULL COMMENT 'Идентификатор производителя',
  `ID_mod` smallint(6) unsigned NOT NULL COMMENT 'Идентификатор модели',
  `ID_src` int(12) unsigned DEFAULT NULL COMMENT 'Индетификатор источника',
  `Code` varchar(20) DEFAULT NULL,
  `Name` varchar(50) DEFAULT NULL COMMENT 'Наименование модификации',
  `Engines` varchar(200) DEFAULT NULL COMMENT 'Коды двигателей',
  `CCM` int(12) DEFAULT NULL COMMENT 'Обьем двигателя, куб. см.',
  `KwHp` varchar(20) DEFAULT NULL COMMENT 'Мощность двигателя Кв/Л.с.',
  `Fuel` varchar(50) DEFAULT NULL COMMENT 'Тип топлива для двигателя',
  `Drive` varchar(50) DEFAULT NULL COMMENT 'Тип привода автомобиля',
  `Doors` tinyint(4) DEFAULT NULL COMMENT 'Количество дверей автомобиля',
  `Trans` varchar(50) DEFAULT NULL COMMENT 'Трансмисия (АКПП, МКПП, Вариатор и т.д.)',
  `Body` varchar(50) DEFAULT NULL COMMENT 'Кузов автомобиля',
  `DateStart` char(6) DEFAULT NULL COMMENT 'Начало производства',
  `DateEnd` char(6) DEFAULT NULL COMMENT 'Окончание производства',
  `Description` varchar(100) DEFAULT NULL COMMENT 'Примечание, описание к модификации',
  `isVisible` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Отображемый (1- да, 0 -нет)',
  `isDeleted` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Удаленный (1- да, 0 - нет)',
  PRIMARY KEY (`ID_typ`),
  UNIQUE KEY `ID_typ` (`ID_typ`),
  KEY `idxSrc` (`ID_src`),
  KEY `idxMain` (`ID_mfa`,`ID_mod`,`isDeleted`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Модификации автомобилей каталога неоригинальных автозапчастей';

CREATE TABLE `cat_alt_manufacturer` (
  `ID_mfa` smallint(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор',
  `ID_src` int(12) DEFAULT NULL COMMENT 'Идентификатор источника',
  `Name` varchar(20) NOT NULL COMMENT 'Наименование производителя',
  `Logo` varchar(50) DEFAULT NULL COMMENT 'Логотип производителя',
  `Childs` smallint(4) unsigned DEFAULT NULL COMMENT 'Количество моделей по марке',
  `isVisible` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Отображение производителя 1 - да, 0 - нет',
  `isDeleted` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Признак удеаления производителя, необходимо для оптимизации.',
  PRIMARY KEY (`ID_mfa`),
  KEY `idxSrc` (`ID_src`),
  KEY `idxVisible` (`isVisible`,`isDeleted`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Производители для каталога неоригинальных запчастей';

CREATE TABLE `cat_alt_link_typ_inf` (
  `ID_typ` int(10) unsigned NOT NULL,
  `ID_art` mediumint(8) unsigned NOT NULL,
  `ID_add` mediumint(8) unsigned NOT NULL,
  `ID_grp` smallint(4) unsigned NOT NULL,
  `Sort` smallint(4) unsigned NOT NULL,
  PRIMARY KEY (`ID_art`,`ID_typ`,`ID_grp`,`ID_add`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `cat_alt_link_typ_eng` (
  `ID_mfa` smallint(4) unsigned NOT NULL COMMENT 'Идентификатор производителя',
  `ID_typ` int(10) unsigned NOT NULL COMMENT 'Идентификатор модификации',
  `ID_eng` smallint(6) unsigned NOT NULL COMMENT 'Идентификатор двигателя',
  `Code` varchar(30) DEFAULT NULL COMMENT 'Кодовое обозначение двигателя',
  `DateStart` char(6) DEFAULT NULL COMMENT 'Производство с...',
  `DateEnd` char(6) DEFAULT NULL COMMENT 'Производство по ...',
  `Sort` tinyint(2) unsigned NOT NULL COMMENT 'Сортировка',
  KEY `idxMfa` (`ID_mfa`),
  KEY `idxMain` (`ID_mfa`,`ID_typ`,`ID_eng`),
  KEY `idxTyp` (`ID_typ`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Связь модификаций с двигателями, каталог неоригинальных запчастей';

CREATE TABLE `cat_alt_link_typ_art` (
  `ID_typ` int(10) unsigned NOT NULL COMMENT 'Идентификатор модификации',
  `ID_art` mediumint(8) unsigned NOT NULL COMMENT 'Идентификатор артикула',
  `ID_sup` smallint(4) unsigned NOT NULL COMMENT 'Идентификатор производителя автозапчасти',
  `ID_grp` smallint(4) unsigned NOT NULL COMMENT 'Идентфикатор группы автозапчастей',
  `Sort` mediumint(8) unsigned NOT NULL COMMENT 'Порядок отображения',
  PRIMARY KEY (`ID_typ`,`ID_grp`,`ID_art`),
  KEY `idxArt` (`ID_art`,`ID_typ`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 PACK_KEYS=1 ROW_FORMAT=COMPRESSED COMMENT='Связь модификаций автомобилей с автозапчастями, неоригинальный каталог';

CREATE TABLE `cat_alt_link_str_grp` (
  `ID_tree` smallint(6) unsigned NOT NULL COMMENT 'Идентификатор дерева',
  `ID_grp` smallint(4) unsigned NOT NULL COMMENT 'Идентификатор группы',
  PRIMARY KEY (`ID_tree`,`ID_grp`),
  UNIQUE KEY `idxGroup` (`ID_grp`,`ID_tree`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Связь дерева с группа автозапчастей';

CREATE TABLE `cat_alt_link_art_mod` (
  `ID_art` mediumint(8) unsigned NOT NULL,
  `ID_mfa` smallint(4) unsigned NOT NULL,
  `ID_mod` smallint(6) unsigned NOT NULL,
  PRIMARY KEY (`ID_art`,`ID_mfa`,`ID_mod`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `cat_alt_link_art_inf` (
  `ID_art` mediumint(8) unsigned NOT NULL,
  `ID_add` mediumint(8) unsigned NOT NULL,
  `ID_grp` smallint(4) unsigned NOT NULL,
  `Sort` tinyint(4) unsigned NOT NULL,
  KEY `idxMain` (`ID_art`,`ID_grp`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `cat_alt_images` (
  `ID_art` mediumint(8) unsigned NOT NULL,
  `path` varchar(65) DEFAULT NULL,
  KEY `idxArt` (`ID_art`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Изображения для запчастей';

CREATE TABLE `cat_alt_groups` (
  `ID_grp` smallint(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор',
  `ID_src` int(12) unsigned NOT NULL COMMENT 'Идентификатор источника',
  `Name` varchar(120) NOT NULL COMMENT 'Наименование',
  `Standard` varchar(110) NOT NULL COMMENT 'Общепринятый',
  `Assembly` varchar(120) NOT NULL COMMENT 'Узел/Механизм',
  `Intended` varchar(120) NOT NULL COMMENT 'Уточнение',
  `Sort` smallint(4) unsigned NOT NULL COMMENT 'Порядок отображения',
  PRIMARY KEY (`ID_grp`),
  KEY `idxSrc` (`ID_src`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Группы запчастей, неоригинальный каталог';

CREATE TABLE `cat_alt_engines` (
  `ID_eng` smallint(6) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор двигателя',
  `ID_mfa` smallint(4) unsigned NOT NULL COMMENT 'Производитель двигателя',
  `ID_src` int(12) DEFAULT NULL COMMENT 'Идентификатор источника',
  `Code` varchar(30) DEFAULT NULL COMMENT 'Кодовое обозначение двигателя',
  PRIMARY KEY (`ID_eng`),
  UNIQUE KEY `ID` (`ID_eng`),
  KEY `idxMain` (`ID_mfa`),
  KEY `idxSrc` (`ID_src`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Двигатели для молдификаций автомобилей, каталог неоригинальных запчастей';

CREATE TABLE `cat_alt_crossing` (
  `ID_art` mediumint(8) unsigned NOT NULL COMMENT 'Идентификатор артикула',
  `ID_cross` mediumint(8) unsigned NOT NULL COMMENT 'Идентифйикатор артикула, кросс',
  KEY `idxArt` (`ID_art`),
  UNIQUE KEY `idxCross` (`ID_cross`,`ID_art`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Кроссы запчастей';

CREATE TABLE `cat_alt_articles` (
  `ID_art` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Идентификатор',
  `ID_sup` smallint(4) unsigned NOT NULL COMMENT 'Производитель автозапчасти',
  `ID_src` int(12) unsigned NOT NULL COMMENT 'Идентификатор источника',
  `Article` varchar(25) NOT NULL COMMENT 'Артикель',
  `Search` varchar(50) DEFAULT NULL COMMENT 'Для поиска',
  `Name` varchar(120) DEFAULT NULL COMMENT 'Наименование',
  `Type` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Тип запчасти (0 - неоригинал с описанием, 1 - неоригинал без описания, 2 - оригинальная запчасть с описанием, 3 - оригинал без описания)',
  `Description` text,
  `isDeleted` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Мутка удаления запчасти (1- удалено, 0 - не удалено)',
  `isVisible` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Отображение в списках (1 - да, 0 - нет)',
  PRIMARY KEY (`ID_art`),
  KEY `idxSrc` (`ID_src`),
  KEY `idxSup` (`ID_sup`),
  KEY `idxSearch` (`Search`,`ID_sup`),
  UNIQUE KEY `idxArticle_tmp` (`Article`,`ID_sup`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Автозапчасти неоригинальные';

CREATE TABLE `cat_alt_additions` (
  `ID_add` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `Name` varchar(120) NOT NULL,
  `Value` varchar(120) NOT NULL,
  PRIMARY KEY (`ID_add`),
  UNIQUE KEY `ID_add` (`ID_add`),
  UNIQUE KEY `idxMain` (`Name`,`Value`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Дополнительная информация по автозапчасти на модификации автомобиля';


-- Создаем временны таблицы в RAM для перформанса
CREATE TABLE `mem_des` (
  `ID_des` int(12) unsigned NOT NULL,
  `ID_txt` int(12) unsigned NOT NULL,
  PRIMARY KEY (`ID_des`)
) ENGINE=MyIsam DEFAULT CHARSET=utf8;

CREATE TABLE `mem_text` (
  `ID_txt` int(12) NOT NULL,
  `Value` varchar(1200) DEFAULT NULL,
  PRIMARY KEY (`ID_txt`)
) ENGINE=MyISAM DEFAULT CHARSET=UTF8;


DELIMITER $$
CREATE FUNCTION `getText`(pDES_ID INTEGER(12))
    RETURNS text CHARSET utf8
    NOT DETERMINISTIC
    CONTAINS SQL
    SQL SECURITY DEFINER
    COMMENT ''
BEGIN
  declare Result varchar(1200);   
  set @Result='';
  
  Select txt.`Value` into @Result
    from `mem_des` des
      inner join mem_text txt on txt.`ID_txt` = des.`ID_txt`
   where des.`ID_des` = pDES_ID 
   limit 0,1;

  RETURN @Result;
END;
$$
DELIMITER ;

SET @lng_id = 16;
SET @cou_id = 188;

truncate table mem_des;
insert into mem_des
select des.`DES_ID`, des.`DES_TEX_ID` 
  from tecdoc_1303.`tof__designations` des 
 where des.`DES_LNG_ID` = @lng_id;
insert ignore into mem_des
select des.`DES_ID`, des.`DES_TEX_ID` 
  from tecdoc_1303.`tof__designations` des 
 where des.`DES_LNG_ID` = 255;
insert ignore into mem_des
select des.CDS_ID, des.CDS_TEX_ID
  from tecdoc_1303.`tof__country_designations` des 
 where des.CDS_LNG_ID = @lng_id and substring(des.cds_ctm, @cou_id,1) = 1;
insert ignore into mem_des
select des.CDS_ID, des.CDS_TEX_ID
  from tecdoc_1303.`tof__country_designations` des 
 where des.CDS_LNG_ID = @lng_id;
insert ignore into mem_des
select des.CDS_ID, des.CDS_TEX_ID
  from tecdoc_1303.`tof__country_designations` des 
 where des.CDS_LNG_ID = 255 and substring(des.cds_ctm, @cou_id,1) = 1;
insert ignore into mem_des
select des.CDS_ID, des.CDS_TEX_ID
  from tecdoc_1303.`tof__country_designations` des 
 where des.CDS_LNG_ID = 255;

truncate table mem_text;
insert ignore into mem_text
select des.ID_txt, txt.`TEX_TEXT`
  from `mem_des` des 
    inner join tecdoc_1303.`tof__des_texts` txt on txt.`TEX_ID` = des.`ID_txt`;
    
-- **************************************************************************************************
-- Очитска таблиц от данных старых
truncate table cat_alt_additions;
truncate table cat_alt_articles;
truncate table cat_alt_crossing;
truncate table cat_alt_engines;
truncate table cat_alt_groups;
truncate table cat_alt_images;
truncate table cat_alt_link_art_inf;
truncate table cat_alt_link_art_mod;
truncate table cat_alt_link_str_grp;
truncate table cat_alt_link_typ_art;
truncate table cat_alt_link_typ_eng; 
truncate table cat_alt_link_typ_inf;
truncate table cat_alt_manufacturer;
truncate table cat_alt_models;
truncate table cat_alt_suppliers;
truncate table cat_alt_tree;
truncate table cat_alt_types;


