CREATE TABLE `cat_alt_link_art_inf_tmp` (
  `ID_art` int(12) NOT NULL,
  `ID_grp` int(12) NOT NULL,
  `Name` varchar(100) DEFAULT NULL,
  `Value` varchar(100) DEFAULT NULL,
  `Sort` tinyint(4) DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

insert into cat_alt_link_art_inf_tmp (ID_art,ID_grp,Name,Value,Sort)
select distinct art.ID_art
     , grp.ID_grp
	 , txt1.`Value`
     , CASE WHEN IFNULL(`acr_value`,'')<>'' THEN `acr_value` ELSE txt2.`Value` END
     , acr_sort
  from tecdoc_1303.`tof__article_criteria`
    inner join `cat_alt_articles` art on art.ID_src = ACR_ART_ID
    inner join `cat_alt_groups` grp on grp.ID_src = ACR_GA_ID  
    left join tecdoc_1303.tof__criteria on CRI_ID = ACR_CRI_ID
    left join mem_des des1 on des1.ID_des = cri_des_id
    left join mem_text txt1 on txt1.ID_txt = des1.ID_txt
    left join mem_des des2 on des2.ID_des = acr_kv_des_id
    left join mem_text txt2 on txt2.ID_txt = des2.ID_txt;

insert ignore into `cat_alt_additions` (`Name`, `Value`)
select `Name`, `Value` from `cat_alt_link_art_inf_tmp`;

insert into `cat_alt_link_art_inf` (ID_art, ID_add, ID_grp, Sort) 
select distinct tmp.`ID_art`, inf.`ID_add`, tmp.`ID_grp`, tmp.`Sort`
  from cat_alt_link_art_inf_tmp tmp
    inner join cat_alt_additions inf on inf.`Name` = tmp.`Name` and inf.`Value` = tmp.`Value`;
    
drop table cat_alt_link_art_inf_tmp; 

insert into cat_alt_images (ID_art, Path)
select ID_art, CONCAT('TOF_GRA_DATA_',gra_tab_nr,'/',gra_grd_id,'.jpg') as Path 
  from tecdoc_1303.`tof__graphics`
    inner join tecdoc_1303.`tof__link_gra_art` on LGA_GRA_ID = GRA_ID
    inner join `cat_alt_articles` on ID_src = LGA_ART_ID;

DELIMITER $$
CREATE DEFINER = 'root'@'192.168.0.3' FUNCTION `getInfoTyp`(
        pTYP_ID smallint(6) unsigned
      , pART_ID mediumint(8) unsigned
      , pGRP_ID smallint(4) unsigned  
    )
    RETURNS text CHARSET utf8
    NOT DETERMINISTIC
    CONTAINS SQL
    SQL SECURITY DEFINER
    COMMENT ''
BEGIN
  declare Result varchar(2000);   
  set @Result='';
  
  select GROUP_CONCAT(CONCAT(`name`,': ', `value`) SEPARATOR '</br>') into @Result  
    from (select LOWER(ads.`Name`) as `name`, GROUP_CONCAT(DISTINCT ads.`Value` SEPARATOR ', ') as `value`
            from cat_alt_link_typ_inf inf
              inner join `cat_alt_additions` ads on ads.`ID_add` = inf.`ID_add`
           where inf.`ID_typ` = pTYP_ID
             and inf.`ID_art` = pART_ID  
             and inf.`ID_grp` = pGRP_ID
           group by ads.Name    
           order by inf.`Sort`) as info;

  RETURN @Result;
END;
$$
DELIMITER ;

DELIMITER $$
CREATE PROCEDURE `FillArtMod`()
    NOT DETERMINISTIC
    MODIFIES SQL DATA
    SQL SECURITY DEFINER
    COMMENT ''
BEGIN
  DECLARE vID_art INT;
  DECLARE done INT DEFAULT 0;
  DECLARE articles CURSOR FOR SELECT ID_art FROM cat_alt_articles;
  DECLARE CONTINUE HANDLER FOR SQLSTATE '02000' SET done = 1;

  OPEN articles;

    REPEAT
       FETCH articles INTO vID_art;
       IF NOT done THEN
         insert ignore into cat_alt_link_art_mod (ID_art, ID_mfa, ID_mod)      
         select ID_art, mds.ID_mfa, mds.ID_mod 
           from `cat_alt_link_typ_art` lnk
             inner join cat_alt_types typ on typ.`ID_typ` = lnk.`ID_typ`
             inner join cat_alt_models mds on mds.`ID_mod` = typ.`ID_mod`
          where lnk.`ID_art` = vID_art;    
       END IF;
    UNTIL done END REPEAT;

  CLOSE articles;
END;
$$
DELIMITER ;

call FillArtMod;
DROP PROCEDURE FillArtMod;

CREATE TABLE `cat_alt_link_typ_inf_tmp` (
  `ID_typ` int(12) DEFAULT NULL,
  `ID_art` int(12) NOT NULL,
  `ID_grp` int(12) NOT NULL,
  `Name` varchar(100) DEFAULT NULL,               
  `Value` varchar(100) DEFAULT NULL,
  `Sort` tinyint(4) DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

ALTER TABLE `cat_alt_link_typ_inf_tmp` ADD INDEX `idxArt` (`ID_art`);

insert into cat_alt_link_typ_inf_tmp (ID_typ, ID_art,ID_grp, `Name`, `Value`, Sort)
select typ.ID_typ
     , art.ID_art
     , grp.ID_grp
     , txt1.`Value`
     , CASE WHEN IFNULL(`lac_value`,'')<>'' THEN `lac_value` ELSE txt2.`Value` END
     , lac_sort
  from tecdoc_1303.`tof__la_criteria`
    inner join tecdoc_1303.tof__link_art on LA_ID = LAC_LA_ID  
    inner join tecdoc_1303.tof__link_la_typ on LAT_LA_ID = LA_ID      
    inner join `cat_alt_articles` art on art.ID_src = LA_ART_ID    
    inner join `cat_alt_groups` grp on grp.ID_src = LA_GA_ID  
    inner join `cat_alt_types` typ on typ.ID_src = LAT_TYP_ID
    left join tecdoc_1303.tof__criteria on CRI_ID = LAC_CRI_ID
    left join mem_des des1 on des1.ID_des = cri_des_id
    left join mem_text txt1 on txt1.ID_txt = des1.ID_txt
    left join mem_des des2 on des2.ID_des = lac_kv_des_id
    left join mem_text txt2 on txt2.ID_txt = des2.ID_txt;

DELIMITER $$
CREATE PROCEDURE `FillTypInf`()
    NOT DETERMINISTIC
    MODIFIES SQL DATA
    SQL SECURITY DEFINER
    COMMENT ''
BEGIN
  DECLARE vID_art INT;
  DECLARE done INT DEFAULT 0;
  DECLARE articles CURSOR FOR SELECT ID_art FROM cat_alt_articles;
  DECLARE CONTINUE HANDLER FOR SQLSTATE '02000' SET done = 1;


  OPEN articles;

    REPEAT
       FETCH articles INTO vID_art;
       IF NOT done THEN
       
         insert ignore into `cat_alt_additions` (`Name`, `Value`)
         select `Name`, `Value` 
           from `cat_alt_link_typ_inf_tmp`
          where ID_art = vID_art;

         insert ignore into cat_alt_link_typ_inf (ID_typ, ID_art, ID_add, ID_grp, Sort)      
         select ID_typ, ID_art, ID_add, ID_grp, Sort
           from `cat_alt_link_typ_inf_tmp` lnk
 			 inner join `cat_alt_additions` ads on ads.`Name` = lnk.`Name` and ads.`Value` = lnk.`Value`	          
          where lnk.`ID_art` = vID_art;    
        
       END IF;
    UNTIL done END REPEAT;

  CLOSE articles;
END;
$$
DELIMITER ;

call FillTypInf;
DROP PROCEDURE FillTypInf;